library aureus;

/* ------------------ CORE GLOBALS -------------------- */
/* Where the widgets that Aureus builds from the objects are contained */

export 'src/Core/foundation.dart';
export 'src/Core/accessibility.dart';
export 'src/Core/coloration.dart';
export 'src/Core/Safety/safetyLib.dart';

export 'src/Core/Foundation/animation.dart';
export 'src/Core/Foundation/palette.dart';
export 'src/Core/Foundation/sensory.dart';
export 'src/Core/Foundation/sizing.dart';
export 'src/Core/Foundation/text.dart';
export 'src/Core/Foundation/decorations.dart';
export 'src/Core/Foundation/enums.dart';

/* ------------------ OBJECTS -------------------- */
/* Where the files that contain the objects that Aureus is built on are contained. Not every widget will have a corresponding object, but more complex widgets do. */

//Observer Object
export 'src/Objects/Observers/ResourceObserver.dart';

//Element Objects
export 'src/Objects/Elements/AlertControllerObjects.dart';

//Component Objects
export 'src/Objects/Components/CardObjects.dart';
export 'src/Objects/Components/Icons.dart';
export 'src/Objects/Components/TabbingBarObjects.dart';

//View Objects
export 'src/Objects/Functionality/DataConsentObjects.dart';
export 'src/Objects/Views/HelpCenterObjects.dart';
export 'src/Objects/Views/OnboardingObjects.dart';
export 'src/Objects/Views/SettingsObjects.dart';

//Functionality Objects
export 'src/Objects/Functionality/ToolLibraryObjects.dart';
export 'src/Objects/Functionality/DataDetailObjects.dart';
export 'src/Objects/Observers/NotificationObserver.dart';

/* ------------------ WIDGETS -------------------- */
/* Where the widgets that Aureus builds from the objects are contained */

//Widget Elements
export 'src/Widgets/Elements/Badges/BadgeElement.dart';

// -------------------------- Accessibility
export 'src/Widgets/Elements/Accessibility/InteractiveSemanticsWrapper.dart';
export 'src/Widgets/Elements/Accessibility/UniversalGestureDetectorElement.dart';

// -------------------------- Cards
// ------------------------------------------------ Standard
export 'src/Widgets/Elements/Cards/Standard/StandardCardElement.dart';
export 'src/Widgets/Elements/Cards/Standard/StandardBadgeCardElement.dart';
export 'src/Widgets/Elements/Cards/Standard/StandardSwitchCardElement.dart';
export 'src/Widgets/Elements/Cards/Standard/StandardSelectionCardElement.dart';
export 'src/Widgets/Elements/Cards/Standard/StandardAccordionCardElement.dart';
// ------------------------------------------------ Detail
export 'src/Widgets/Elements/Cards/Detail/DetailCardElement.dart';
export 'src/Widgets/Elements/Cards/Detail/DetailBadgeCardElement.dart';
export 'src/Widgets/Elements/Cards/Detail/DetailCarouselCardElement.dart';
export 'src/Widgets/Elements/Cards/Detail/CategoryIconDetailCardElement.dart';
// ------------------------------------------------ Complex
export 'src/Widgets/Elements/Cards/Complex/ComplexCardElement.dart';
export 'src/Widgets/Elements/Cards/Complex/ComplexBadgeCardElement.dart';
export 'src/Widgets/Elements/Cards/Complex/ComplexSwitchCardElement.dart';
// ------------------------------------------------ Grid
export 'src/Widgets/Elements/Cards/Grid/GridCardElement.dart';
export 'src/Widgets/Elements/Cards/Grid/GridBadgeCardElement.dart';
// ------------------------------------------------ Data Visualization
// Some of these are in beta, and not for use as of right now.
export 'src/Widgets/Elements/Cards/Data Detail/AddressDataCardElement.dart';
export 'src/Widgets/Elements/Cards/Data Detail/BaseDataCardElement.dart';
// export 'src/Widgets/Elements/Cards/Data Detail/PhotoDataCardElement.dart';
export 'src/Widgets/Elements/Cards/Data Detail/TextFieldDataCardElement.dart';
export 'src/Widgets/Elements/Cards/Data Detail/TextViewDataCardElement.dart';
export 'src/Widgets/Elements/Cards/Data Detail/TimePickerDataCardElement.dart';
export 'src/Widgets/Elements/Cards/Data Detail/PromptSelectionListCardElement.dart';
// export 'src/Widgets/Elements/Cards/Data Detail/VideoRecordingDataCardElement.dart';
// export 'src/Widgets/Elements/Cards/Data Detail/VoiceRecordingDataCardElement.dart';

// -------------------------- Info Hierachy
export 'src/Widgets/Elements/Info Hierarchy/ArticleViewElement.dart';
export 'src/Widgets/Elements/Info Hierarchy/TabSubheaderElement.dart';
export 'src/Widgets/Elements/Info Hierarchy/MissionHeaderElement.dart';
export 'src/Widgets/Elements/Info Hierarchy/PageHeaderElement.dart';
export 'src/Widgets/Elements/Info Hierarchy/DividerElement.dart';
export 'src/Widgets/Elements/Info Hierarchy/DividingHeaderElement.dart';

// -------------------------- Misc Elements
export 'src/Widgets/Elements/Misc/ContainerWrapperElement.dart';
export 'src/Widgets/Elements/Misc/FloatingContainerElement.dart';
export 'src/Widgets/Elements/Misc/CompletionCircleElement.dart';
export 'src/Widgets/Elements/Misc/LoadingCircleElement.dart';
export 'src/Widgets/Elements/Misc/ProgressIndicatorElement.dart';
export 'src/Widgets/Elements/Misc/TimerElement.dart';
export 'src/Widgets/Elements/Misc/PulseShadowElement.dart';
export 'src/Widgets/Elements/Misc/EclipseShadowElement.dart';

// -------------------------- User Input
export 'src/Widgets/Elements/User Input/TextFieldComponent.dart';
export 'src/Widgets/Elements/User Input/TextViewComponent.dart';
export 'src/Widgets/Elements/User Input/SliderElement.dart';

//Exporting lib widget components
// -------------------------- Alert Controllers
export 'src/Widgets/Components/Alert Controllers/CenteredAlertControllerComponent.dart';
export 'src/Widgets/Components/Alert Controllers/ContentWarningComponent.dart';
export 'src/Widgets/Components/Alert Controllers/BottomActionSheetComponent.dart';
export 'src/Widgets/Components/Alert Controllers/TextFieldAlertControllerComponent.dart';

// -------------------------- Buttons
export 'src/Widgets/Components/Buttons/FullWidthButtonElement.dart';
export 'src/Widgets/Components/Buttons/IconButtonElement.dart';
export 'src/Widgets/Components/Buttons/SmolButtonElement.dart';
export 'src/Widgets/Components/Buttons/StandardButtonElement.dart';
export 'src/Widgets/Components/Buttons/StandardIconButtonElement.dart';

// -------------------------- Collection Views
export 'src/Widgets/Components/Collection Views/DetailCardCarouselComponent.dart';
export 'src/Widgets/Components/Collection Views/EmergencyActionBarComponent.dart';

// -------------------------- Communication
export 'src/Widgets/Components/Communication/MessageBubbleComponent.dart';
export 'src/Widgets/Components/Communication/NotificationComponent.dart';
export 'src/Widgets/Components/Communication/SearchBarComponent.dart';
export 'src/Widgets/Components/Communication/SendFieldComponent.dart';
export 'src/Widgets/Components/Communication/BlankScreenComponent.dart';
export 'src/Widgets/Components/Communication/CookieBannerComponent.dart';
export 'src/Widgets/Components/Communication/ExitBarComponent.dart';
export 'src/Widgets/Components/Communication/BannerNotificationComponent.dart';
export 'src/Widgets/Components/Communication/SwitchComponent.dart';
export 'src/Widgets/Components/Communication/NumberPadComponent.dart';

// -------------------------- Tabbing Bars
export 'src/Widgets/Components/Tabbing Bars/IconTabbingBarComponent.dart';
export 'src/Widgets/Components/Tabbing Bars/NavBarComponent.dart';
export 'src/Widgets/Components/Tabbing Bars/IteratingTabbingComponent.dart';
export 'src/Widgets/Components/Tabbing Bars/SmolTextTabbingBarComponent.dart';
export 'src/Widgets/Components/Tabbing Bars/VerticalSideNavBarComponent.dart';

//Exporting lib widget views

// -------------------------- Onboarding
export 'src/Widgets/Views/Onboarding/OnboardingDemoView.dart';
export 'src/Widgets/Views/Onboarding/OnboardingInformationView.dart';
export 'src/Widgets/Views/Onboarding/OnboardingLandingView.dart';

// -------------------------- Utilities
export 'src/Widgets/Views/Utilities/DataConsentView.dart';
export 'src/Widgets/Views/Utilities/2FAVerificationView.dart';
export 'src/Widgets/Views/Utilities/SettingsView.dart';
export 'src/Widgets/Views/Utilities/PasscodeView.dart';
export 'src/Widgets/Views/Utilities/ChangeAccountItemView.dart';

// -------------------------- Info Hierarchy
export 'src/Widgets/Views/Info Hierarchy/HelpCenterView.dart';
export 'src/Widgets/Views/Info Hierarchy/DataDetailView.dart';
export 'src/Widgets/Views/Info Hierarchy/CheckboxArticleView.dart';

// -------------------------- Landing
export 'src/Widgets/Views/Landing/LandingPageView.dart';
export 'src/Widgets/Views/Landing/SignInView.dart';
export 'src/Widgets/Views/Landing/SplashScreenView.dart';

// -------------------------- Supporting
export 'src/Widgets/Views/Supporting/ContainerView.dart';
export 'src/Widgets/Views/Supporting/NotificationOverlayView.dart';

// -------------------------- Misc
export 'src/Widgets/Views/Misc/PoetryGradientView.dart';

// -------------------------- Safety Plan
export 'src/Widgets/Views/Safety Plan/SafetyPlanOptInView.dart';
export 'src/Widgets/Views/Safety Plan/SafetyPlanOptionsView.dart';
export 'src/Widgets/Views/Safety Plan/SafetyPlanLogInAuditView.dart';
export 'src/Widgets/Views/Safety Plan/SafetyPlanSettingsView.dart';

// -------------------------- Tool Library
export 'src/Widgets/Views/Tool Library/ToolDetailView.dart';
export 'src/Widgets/Views/Tool Library/ToolNextStepView.dart';
export 'src/Widgets/Views/Tool Library/ToolSummaryView.dart';
export 'src/Widgets/Views/Tool Library/ToolTemplateCardCarouselView.dart';

//Exporting lib tool templates

export 'src/Widgets/Tools/BaseCardToolTemplate.dart';
export 'src/Widgets/Tools/BasePageToolTemplate.dart';

// -------------------------- Mini Tools
export 'src/Widgets/Tools/Mini Tools/CameraInputToolTemplate.dart';
export 'src/Widgets/Tools/Mini Tools/ColorSpectrumToolTemplate.dart';
export 'src/Widgets/Tools/Mini Tools/MapInputToolTemplate.dart';
export 'src/Widgets/Tools/Mini Tools/MicrophoneInputToolTemplate.dart';
export 'src/Widgets/Tools/Mini Tools/PulseInputToolTemplate.dart';
export 'src/Widgets/Tools/Mini Tools/SensoryMapToolTemplate.dart';
export 'src/Widgets/Tools/Mini Tools/SketchToolTemplate.dart';
export 'src/Widgets/Tools/Mini Tools/TimerToolTemplate.dart';
export 'src/Widgets/Tools/Mini Tools/AdaptiveInputSelectionToolTemplate.dart';
export 'src/Widgets/Tools/Mini Tools/AdaptiveInputToolTemplate.dart';
export 'src/Widgets/Tools/Mini Tools/VideoInputToolTemplate.dart';

// -------------------------- User Input
export 'src/Widgets/Tools/User Input/DualColumnInputToolTemplate.dart';
export 'src/Widgets/Tools/User Input/PromptListUserInputToolTemplate.dart';
export 'src/Widgets/Tools/User Input/SingleInputToolTemplate.dart';
export 'src/Widgets/Tools/User Input/SingleSliderInputToolTemplate.dart';
export 'src/Widgets/Tools/User Input/TriInputToolTemplate.dart';
export 'src/Widgets/Tools/User Input/DatePickerInputToolTemplate.dart';
export 'src/Widgets/Tools/User Input/TimePickerInputToolTemplate.dart';

// -------------------------- User Selection
export 'src/Widgets/Tools/User Selection/ListViewButtonSelectToolTemplate.dart';
export 'src/Widgets/Tools/User Selection/ListViewPickerSelectToolTemplate.dart';
export 'src/Widgets/Tools/User Selection/YesNoButtonSelectToolTemplate.dart';
export 'src/Widgets/Tools/User Selection/GridCardSelectToolTemplate.dart';
